pub struct TaskCompletion { /* private fields */ }Expand description
Evaluates whether the agent successfully completed its assigned task.
Implementations
Sourceimpl TaskCompletion
impl TaskCompletion
Sourcepub fn new(provider: Arc<dyn JudgeProvider>) -> Self
pub fn new(provider: Arc<dyn JudgeProvider>) -> Self
Create a new task completion evaluator with the given judge provider.